@@ -51,8 +51,8 @@ class Meek(object):
         ) = get_tor_paths()
 
         self.meek_proxies = {}
-        self.meek_url = "https://moat.torproject.org.global.prod.fastly.net/"
-        self.meek_front = "cdn.sstatic.net"
+        self.meek_url = "https://1723079976.rsc.cdn77.org/"
+        self.meek_front = "www.phpmyadmin.net"
         self.meek_env = {
             "TOR_PT_MANAGED_TRANSPORT_VER": "1",
             "TOR_PT_CLIENT_TRANSPORTS": "meek",
